@@ -375,9 +375,6 @@ class FileRecord:
             if self._name[0:1] == b"\xe5":
                 self._name = b"_" + self._name[1:]
     
-    def __bytes__(self):
-        return b""
-    
     def __repr__(self):
         name = self.name.decode("latin1")
         ext  = self.ext.decode("latin1")
