@@ -3,6 +3,9 @@ Module to parse Master Boot Record partition tables and return a (reasonably)
 sane object.
 """
 # TODO: add EBR support
+# TODO: add comparisson operators for the classes?
+#       this just came up after a small refactoring, and it'd be a simpler way
+#       to test things
 import struct
 
 
@@ -21,19 +24,34 @@ class Partition:
         0x0f: "Microsoft Extended LBA",
     }   # this dict could be extended to include more types
 
-    def __init__(self, data):
+    def __init__(self, data=bytes(16), *, 
+                 bootable=None, chs_start=None, type=None, chs_end=None,
+                 start=None, size=None
+        ):
         """
         :param data: raw bytes for the MBR record, at least 16 bytes long
         """
+        def _chs(value):
+            """A little helper for CHS parsing."""
+            head, sector, cylinder = struct.unpack("<3B", value)
+            cylinder = ((sector & 0b11000000) << 2) | cylinder
+            sector   =   sector & 0b00111111
+            return (cylinder, head, sector)
+
+        p_bootable  = data[0]
+        p_chs_start = _chs(data[1:4])
+        p_type      = data[4]
+        p_chs_end   = _chs(data[5:8])
+        p_start,    = struct.unpack("<I", data[8:12])
+        p_size,     = struct.unpack("<I", data[12:16])
+        # and now we set, either the overridden values or the parsed ones
         self._raw_data = data
-        self._bootable  = 0x0
-        self._chs_start = (0x0, 0x0, 0x0)
-        self._type      = 0x0
-        self._chs_end   = (0x0, 0x0, 0x0)
-        self._start     = 0x0
-        self._size      = 0
-        # after setting the attributes for the instance, we parse the raw data
-        self._parse()
+        self.bootable  = bootable or p_bootable
+        self.chs_start = chs_start or p_chs_start
+        self.type      = type or p_type
+        self.chs_end   = chs_end or p_chs_end
+        self.start     = start or p_start
+        self.size      = size or p_size
     
     def __bytes__(self):
         """
@@ -65,26 +83,6 @@ class Partition:
         ret = f"< Partition - {self.type} - boot: {self.bootable} @ {self.start} of {self.size} >"
         return ret
     
-    def _parse(self):
-        """
-        Parses self._raw_data and uses it to modifiy/complete the internal state
-        of Record.
-        """
-        def _chs(value):
-            head, sector, cylinder = struct.unpack("<3B", value)
-            cylinder = ((sector & 0b11000000) << 2) | cylinder
-            sector   =   sector & 0b00111111
-            return (cylinder, head, sector)
-
-        data = self._raw_data
-        self._bootable  = data[0]
-        # CHS addresses should be 0 in any recent MBR, stil...
-        self._chs_start = _chs(data[1:4])
-        self._type      = data[4]
-        self._chs_end   = _chs(data[5:8])
-        self._start,    = struct.unpack("<I", data[8:12])
-        self._size,     = struct.unpack("<I", data[12:16])
-    
     @property
     def bootable(self):
         """
@@ -100,7 +98,7 @@ class Partition:
         if value:
             self._bootable = 0x80
         else:
-            self.bootable = 0x0
+            self._bootable = 0x0
     
     @property
     def chs_start(self):
@@ -113,7 +111,7 @@ class Partition:
     
     @chs_start.setter
     def chs_start(self, value):
-        pass
+        self._chs_start = value
     
     @property
     def type(self):
@@ -128,6 +126,7 @@ class Partition:
     
     @type.setter
     def type(self, value):
+        value = int(value)
         value = min(max(0, value), 255)  # clip it to 0..255
         self._type = value
     
@@ -141,8 +140,8 @@ class Partition:
         return self._chs_end
     
     @chs_end.setter
-    def chs_start(self, value):
-        pass
+    def chs_end(self, value):
+        self._chs_end = value
 
     @property
     def start(self):
@@ -154,6 +153,7 @@ class Partition:
     
     @start.setter
     def start(self, value):
+        value = int(value)
         value = min(max(0, value), 0xffffffff)
         self._start = value
     
@@ -167,6 +167,7 @@ class Partition:
     
     @size.setter
     def size(self, value):
+        value = int(value)
         value = min(max(0, value), 0xffffffff)
         self._size = value
     
@@ -178,13 +179,36 @@ class Table:
     """
     Handles one Master Boot Record (simple case without Extended Partitions).
     """
-    def __init__(self, data):
+    def __init__(self, data=bytes(512), *,
+                 boot_code=None, partitions=None
+        ):
         """
         :param data: raw bytes read from an MBR (at least 512 bytes long)
         """
         self._raw_data = data
-        self.partitions = []
-        self._parse()
+        data = data[446:]
+        p_boot_code = self._raw_data[:446]
+        p_parts = filter(
+            lambda x: x != b"\x00" * 16,  # filter out empty partitions
+            (data[i * 16: i * 16 + 16] for i in range(4))
+        )
+        p_partitions = [Partition(p) for p in p_parts]
+        # this implementation is "good enough", but not thorough
+        # -- the legacy files have a larger implementation that includes
+        #    extended partitions parsing
+        # override parsed values with keyword-only arguments
+        self.boot_code = boot_code or p_boot_code
+        self.partitions = partitions or p_partitions
+
+    def __bytes__(self):
+        ret = bytearray(512)
+        ret[:446] = self.boot_code
+        parts = b"".join(bytes(p) for p in self.partitions)
+        parts = parts[:64]
+        psize = len(parts)
+        ret[446: 446 + psize] = parts
+        ret[510: 512] = b"\x55\xaa"
+        return bytes(ret)
     
     def __repr__(self):
         ret  = [f"< MBR Partition Table @ {id(self)} >"]
@@ -192,19 +216,6 @@ class Table:
                [f"    {p}" for p in self.partitions]
         )
         return "\n".join(ret)
-    
-    def _parse(self):
-        """
-        Parses the raw data passed during initialization. Does not return, but
-        changes the self.partitions list.
-        """
-        data = self._raw_data[446:]
-        p_parts = filter(
-            lambda x: x != b"\x00" * 16,  # filter out empty partitions
-            (data[i * 16: i * 16 + 16] for i in range(4))
-        )
-        self.partitions = [Partition(p) for p in p_parts]
-        # this implementation is "good enough", but not thorough
-        # -- the legacy files have a larger implementation that includes
-        #    extended partitions parsing
 
+    def to_bytes(self):
+        return bytes(self)
